#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Reflection;
using NUnit.Framework;
using Utilities.IO;
using System.IO;
using Utilities.Testing;

namespace Utilities.Test.IO
{
  public class ResourceStreamGetterFixture : TestFixtureBase
  {
    [Test]
    public void GetStream()
    {
      ResourceStreamGetter streamGetter = new ResourceStreamGetter();
      streamGetter.ResourceAssembly = Assembly.GetExecutingAssembly();
      streamGetter.ResourceName = "Utilities.Test.IO.Resources.ResourceStreamGetter.xml";

      using (Stream s = streamGetter.GetStream())
      {
        Assert.IsNotNull(s);
        Assert.IsInstanceOfType(typeof(UnmanagedMemoryStream), s);

        using (StreamReader sr = new StreamReader(s))
        {
          string content = sr.ReadToEnd();

          StringAssert.Contains("ResourceStreamGetter", content);
        }
      }
    }

    [Test]
    [ExpectedException(typeof(InvalidOperationException), ExpectedMessage = "ResourceName must be set.")]
    public void GetStreamUninitialized()
    {
      ResourceStreamGetter streamGetter = new ResourceStreamGetter();

      streamGetter.GetStream();
    }

    [Test]
    [ExpectedException(typeof(Exception), ExpectedMessage = "Could not find resource 'How now brown cow?' in assmebly 'Utilities, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null'.")]
    public void GetStreamNotFound()
    {
      ResourceStreamGetter streamGetter = new ResourceStreamGetter();
      streamGetter.ResourceName = "How now brown cow?";

      streamGetter.GetStream();
    }
  }
}