#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using Utilities.Miscellaneous;
using Utilities.Testing;

namespace Utilities.Test.Miscellaneous
{
  public class MiscellaneousUtilsFixture : TestFixtureBase
  {
    [System.ComponentModel.Description("Description: DescriptionTestEnumeration")]
    public enum DescriptionTestEnumeration
    {
      [System.ComponentModel.Description("Description: EnumOne")]
      EnumOne,
      [System.ComponentModel.Description("Description: EnumTwo")]
      EnumTwo
    }

    public class DescriptionTestClass
    {
      [System.ComponentModel.Description("Description: ToString")]
      public override string ToString()
      {
        return "Overriden ToString";
      }
    }

    [Test]
    public void GetDescription()
    {
      string result;

      result = MiscellaneousUtils.GetDescription(DescriptionTestEnumeration.EnumOne);
      Assert.AreEqual("Description: EnumOne", result);

      result = MiscellaneousUtils.GetDescription(DescriptionTestEnumeration.EnumTwo);
      Assert.AreEqual("Description: EnumTwo", result);

      result = MiscellaneousUtils.GetDescription(typeof(DescriptionTestEnumeration));
      Assert.AreEqual("Description: DescriptionTestEnumeration", result);

      result = MiscellaneousUtils.GetDescription(typeof(DescriptionTestClass).GetMethod("ToString"));
      Assert.AreEqual("Description: ToString", result);
    }

    [Test]
    public void GetDescriptions()
    {
      IList<string> descriptions = MiscellaneousUtils.GetDescriptions(Enum.GetValues(typeof(DescriptionTestEnumeration)));

      Assert.AreEqual(2, descriptions.Count);
      Assert.AreEqual("Description: EnumOne", descriptions[0]);
      Assert.AreEqual("Description: EnumTwo", descriptions[1]);
    }
  }
}
